==> amlaidatatests-0.1.11.tar.gz: amlaidatatests-0.1.11/generated_sql/duckdb/P050-CountFrequencyValues-is_entity_deleted_party.sql <==
-- More than 40% of entities have is_entity_deleted = TRUE. Warning.
SELECT
  COUNT(*) AS "CountStar()"
FROM (
  SELECT
    *
  FROM (
    SELECT
      "t4"."is_entity_deleted",
      "t4"."value_cnt",
      "t4"."value_cnt" / SUM("t4"."value_cnt") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "proportion"
    FROM (
      SELECT
        "t3"."is_entity_deleted",
        COUNT(*) AS "value_cnt"
      FROM (
        SELECT
          *
        FROM (
          SELECT
            "t1"."party_id",
            "t1"."validity_start_time",
            "t1"."is_entity_deleted",
            "t1"."source_system",
            "t1"."type",
            "t1"."birth_date",
            "t1"."establishment_date",
            "t1"."occupation",
            "t1"."gender",
            "t1"."nationalities",
            "t1"."residencies",
            "t1"."exit_date",
            "t1"."join_date",
            "t1"."assets_value_range",
            "t1"."civil_status_code",
            "t1"."education_level_code",
            ROW_NUMBER() OVER (PARTITION BY "t1"."party_id" ORDER BY "t1"."validity_start_time" DESC ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - 1 AS "row_num"
          FROM (
            SELECT
              *
            FROM "PLACEHOLDER"."party" AS "t0"
            WHERE
              "t0"."is_entity_deleted" IN (FALSE, NULL)
          ) AS "t1"
        ) AS "t2"
        WHERE
          "t2"."row_num" = 0 AND "t2"."is_entity_deleted" IS NOT NULL
      ) AS "t3"
      GROUP BY
        1
    ) AS "t4"
  ) AS "t5"
  WHERE
    (
      (
        "t5"."proportion" >= 0.4
      ) OR CAST(NULL AS BOOLEAN)
    )
    AND "t5"."is_entity_deleted" = TRUE
) AS "t6"

==> amlaidatatests-0.1.15.tar.gz: amlaidatatests-0.1.15/generated_sql/duckdb/P050-CountFrequencyValues-is_entity_deleted_party.sql <==
-- Tests: party.is_entity_deleted
-- Severity: WARN
-- Description: More than 40% of entities have is_entity_deleted = TRUE.
-- Interpretation: When count > 0, you should verify is_entity_deleted is correctly mapped. More than 40% of entities being deleted is a high number.
SELECT
  COUNT(*) AS "CountStar()"
FROM (
  SELECT
    *
  FROM (
    SELECT
      "t4"."is_entity_deleted",
      "t4"."value_cnt",
      "t4"."value_cnt" / SUM("t4"."value_cnt") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "proportion"
    FROM (
      SELECT
        "t3"."is_entity_deleted",
        COUNT(*) AS "value_cnt"
      FROM (
        SELECT
          *
        FROM (
          SELECT
            "t1"."party_id",
            "t1"."validity_start_time",
            "t1"."is_entity_deleted",
            "t1"."source_system",
            "t1"."type",
            "t1"."birth_date",
            "t1"."establishment_date",
            "t1"."occupation",
            "t1"."gender",
            "t1"."nationalities",
            "t1"."residencies",
            "t1"."exit_date",
            "t1"."join_date",
            "t1"."assets_value_range",
            "t1"."civil_status_code",
            "t1"."education_level_code",
            ROW_NUMBER() OVER (PARTITION BY "t1"."party_id" ORDER BY "t1"."validity_start_time" DESC ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - 1 AS "row_num"
          FROM (
            SELECT
              *
            FROM "PLACEHOLDER"."party" AS "t0"
            WHERE
              NOT (
                "t0"."is_entity_deleted"
              ) OR (
                "t0"."is_entity_deleted" IS NULL
              )
          ) AS "t1"
        ) AS "t2"
        WHERE
          "t2"."row_num" = 0 AND "t2"."is_entity_deleted" IS NOT NULL
      ) AS "t3"
      GROUP BY
        1
    ) AS "t4"
  ) AS "t5"
  WHERE
    (
      (
        "t5"."proportion" >= 0.4
      ) OR CAST(NULL AS BOOLEAN)
    )
    AND "t5"."is_entity_deleted" = TRUE
) AS "t6"
